@@ -2,12 +2,11 @@ package Perl::Dist;
 
 use 5.006;
 use strict;
-use Perl::Dist::Inno ();
+use base 'Perl::Dist::Inno';
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION};
 BEGIN {
-        $VERSION = '1.05_04';
-	@ISA     = 'Perl::Dist::Inno';
+        $VERSION = '1.01';
 }
 
 1;
@@ -113,13 +112,7 @@ Better uninstall support and upgradability.
 
 =back
 
-=head1 SUPPORT
-
-Bugs should be reported via the CPAN bug tracker at
-
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Dist>
-
-=head1 AUTHORS
+=head1 AUTHOR
 
 Adam Kennedy <adamk@cpan.org>
 
