@@ -43,14 +43,13 @@ This class inherits from L<Perl::Dist::Asset> and shares its API.
 =cut
 
 use strict;
-use Carp              ();
-use Params::Util      qw{ _STRING _HASH };
-use Perl::Dist::Asset ();
+use Carp           'croak';
+use Params::Util   qw{ _STRING _HASH };
+use base 'Perl::Dist::Asset';
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.05_04';
-	@ISA     = 'Perl::Dist::Asset';
+	$VERSION = '1.01';
 }
 
 use Object::Tiny qw{
@@ -124,10 +123,10 @@ sub new {
 
 	# Check params
 	unless ( _STRING($self->name) ) {
-		Carp::croak("Missing or invalid name param");
+		croak("Missing or invalid name param");
 	}
 	unless ( _STRING($self->install_to) or _HASH($self->install_to) ) {
-		Carp::croak("Missing or invalid install_to param");
+		croak("Missing or invalid install_to param");
 	}
 
 	return $self;
