@@ -35,14 +35,13 @@ This class inherits from L<Perl::Dist::Asset> and shares its API.
 =cut
 
 use strict;
-use Carp              ();
-use Params::Util      qw{ _STRING };
-use Perl::Dist::Asset ();
+use Carp         'croak';
+use Params::Util qw{ _STRING };
+use base 'Perl::Dist::Asset';
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.05_04';
-	@ISA     = 'Perl::Dist::Asset';
+	$VERSION = '1.01';
 }
 
 use Object::Tiny qw{
@@ -88,7 +87,7 @@ sub new {
 
 	# Check params
 	unless ( _STRING($self->install_to) ) {
-		Carp::croak("Missing or invalid install_to param");
+		croak("Missing or invalid install_to param");
 	}
 
 	return $self;
