@@ -50,14 +50,13 @@ This class inherits from L<Perl::Dist::Asset> and shares its API.
 =cut
 
 use strict;
-use Carp              ();
-use Params::Util      qw{ _STRING _HASH };
-use Perl::Dist::Asset ();
+use Carp         'croak';
+use Params::Util qw{ _STRING _HASH };
+use base 'Perl::Dist::Asset';
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.05_04';
-	@ISA     = 'Perl::Dist::Asset';
+	$VERSION = '1.01';
 }
 
 use Object::Tiny qw{
@@ -91,19 +90,19 @@ sub new {
 
 	# Check params
 	unless ( _STRING($self->name) ) {
-		Carp::croak("Missing or invalid name param");
+		croak("Missing or invalid name param");
 	}
 	unless ( ! defined $self->license or _HASH($self->license) ) {
-		Carp::croak("Missing or invalid license param");
+		croak("Missing or invalid license param");
 	}
 	unless ( defined $self->unpack_to and ! ref $self->unpack_to ) {
-		Carp::croak("Missing or invalid unpack_to param");
+		croak("Missing or invalid unpack_to param");
 	}
 	unless ( _STRING($self->install_to) or _HASH($self->install_to) ) {
-		Carp::croak("Missing or invalid install_to param");
+		croak("Missing or invalid install_to param");
 	}
 	unless ( _HASH($self->build_a) ) {
-		Carp::croak("Missing or invalid build_a param");
+		croak("Missing or invalid build_a param");
 	}
 
 	return $self;
