@@ -1,14 +1,12 @@
 package Perl::Dist::Asset::PAR;
-
 use strict;
-use Carp              ();
-use Params::Util      qw{ _STRING };
-use Perl::Dist::Asset ();
+use Carp           'croak';
+use Params::Util   qw{ _STRING };
+use base 'Perl::Dist::Asset';
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.05_04';
-	@ISA     = 'Perl::Dist::Asset';
+	$VERSION = '1.01';
 }
 
 use Object::Tiny qw{
@@ -94,7 +92,7 @@ sub new {
 
 	# Check params
 	unless ( _STRING($self->name) ) {
-		Carp::croak("Missing or invalid name param");
+		croak("Missing or invalid name param");
 	}
 
 	return $self;
