@@ -3,13 +3,12 @@ package Perl::Dist::Bootstrap;
 use 5.006;
 use strict;
 use warnings;
-use File::Remove        ();
-use Perl::Dist::Vanilla ();
+use base 'Perl::Dist::Vanilla';
+use File::Remove ();
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.05_04';
-	@ISA     = 'Perl::Dist::Vanilla';
+	$VERSION = '1.01';
 }
 
 
