@@ -2,32 +2,19 @@ package Perl::Dist::Util::Toolchain;
 
 use 5.005;
 use strict;
-use Carp                 ();
-use Params::Util         qw{ _HASH _ARRAY };
-use Module::CoreList     ();
-use IO::Capture::Stdout  ();
-use IO::Capture::Stderr  ();
-use Process::Delegatable ();
-use Process::Storable    ();
-use Process              ();
+use Carp 'croak';
+use Params::Util '_HASH', '_ARRAY';
+use Module::CoreList    ();
+use IO::Capture::Stdout ();
+use IO::Capture::Stderr ();
+use base 'Process::Delegatable',
+         'Process::Storable',
+         'Process';
 
-use vars qw{$VERSION @ISA @DELEGATE};
+use vars qw{$VERSION @DELEGATE};
 BEGIN {
-	$VERSION  = '1.05_04';
-	@ISA      = qw{
-		Process::Delegatable
-		Process::Storable
-		Process
-	};
+	$VERSION  = '1.01';
 	@DELEGATE = ();
-
-	# Automatically handle delegation within the test suite
-	if ( $ENV{HARNESS_ACTIVE} ) {
-		require Probe::Perl;
-		@DELEGATE = (
-			Probe::Perl->find_perl_interpreter, '-Mblib',
-		);
-	}
 }
 
 my %MODULES = (
@@ -94,10 +81,10 @@ sub new {
 
 	# Check the Perl version
 	unless ( defined $self->perl_version ) {
-		Carp::croak("Did not provide a perl_version param");
+		croak("Did not provide a perl_version param");
 	}
 	unless ( $MODULES{$self->perl_version} ) {
-		Carp::croak("Perl version '" . $self->perl_version . "' is not supported in $class");
+		croak("Perl version '" . $self->perl_version . "' is not supported in $class");
 	}
 
 	# Populate the modules array if needed
@@ -109,12 +96,12 @@ sub new {
 	$self->{corelist} = $Module::CoreList::version{$self->perl_version}
 	                 || $Module::CoreList::version{$self->perl_version+0};
 	unless ( _HASH($self->{corelist}) ) {
-		Carp::croak("Failed to find module core versions for Perl " . $self->perl_version);
+		croak("Failed to find module core versions for Perl " . $self->perl_version);
 	}
 
 	# Check forced dists, if applicable
 	if ( $self->{force} and ! _HASH($self->{force}) ) {
-		Carp::croak("The force param must be a HASH reference");
+		croak("The force param must be a HASH reference");
 	}
 
 	# Create the distribution array
@@ -153,15 +140,14 @@ sub prepare {
 	CPAN->import();
 
 	# Load the latest index
-	eval {
+	SCOPE: {
 		local $SIG{__WARN__} = sub { 1 };
 		CPAN::Index->reload;
-	};
+	}
 
 	$stdout->stop;
 	$stderr->stop;
-
-	return $@ ? '' : 1;
+	return 1;
 }
 
 sub run {
