@@ -3,12 +3,11 @@ package Perl::Dist::Vanilla;
 use 5.006;
 use strict;
 use warnings;
-use Perl::Dist;
+use base 'Perl::Dist';
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '19';
-	@ISA     = 'Perl::Dist';
+	$VERSION = '17';
 }
 
 
@@ -60,19 +59,13 @@ sub new {
 # Lazily default the full name
 sub app_ver_name {
 	$_[0]->{app_ver_name} or
-	$_[0]->app_name
-		. ($_[0]->portable ? ' Portable' : '')
-		. ' ' . $_[0]->perl_version_human
-		. ' Build ' . $_[0]->VERSION;
+	$_[0]->app_name . ' ' . $_[0]->perl_version_human . ' ' . $_[0]->VERSION;
 }
 
 # Lazily default the file name
 sub output_base_filename {
 	$_[0]->{output_base_filename} or
-	'vanilla-perl'
-		. ($_[0]->portable ? '-portable' : '')
-		. '-' . $_[0]->perl_version_human
-		. '-build-' . $_[0]->VERSION;
+	'vanilla-perl-' . $_[0]->perl_version_human . '-build-' . $_[0]->VERSION;
 }
 
 
@@ -87,24 +80,32 @@ sub install_perl_5100_bin {
 	$self->SUPER::install_perl_5100_bin(@_);
 
 	# Overwrite the CPAN config to be relocatable
-	if ( $self->portable ) {
-		$self->install_file(
-			share      => 'Perl-Dist vanilla/perl-5.10.0/lib/Config.pm',
-			install_to => 'perl/lib/Config.pm',
-		);
-		$self->install_file(
-			share      => 'Perl-Dist vanilla/perl-5.10.0/lib/Config_heavy.pl',
-			install_to => 'perl/lib/Config_heavy.pl',
-		);
-		$self->install_file(
-			share      => 'Perl-Dist vanilla/perl-5.10.0/lib/CPAN/Config.pm',
-			install_to => 'perl/lib/CPAN/Config.pm',
-		);
-	}
+	$self->install_file(
+		share      => 'Perl-Dist vanilla/Config5100.pm',
+		install_to => 'perl/lib/Config.pm',
+	);
+	$self->install_file(
+		share      => 'Perl-Dist vanilla/Config_heavy5100.pl',
+		install_to => 'perl/lib/Config_heavy.pl',
+	);
+	$self->install_file(
+		share      => 'Perl-Dist vanilla/CPAN_Config.pm',
+		install_to => 'perl/lib/CPAN/Config.pm',
+	);
 
 	return 1;
 }
 
+sub install_perl_5100_toolchain_object {
+	Perl::Dist::Util::Toolchain->new(
+		perl_version => $_[0]->perl_version_literal,
+		force        => {
+			'ExtUtils::CBuilder' => 'KWILLIAMS/ExtUtils-CBuilder-0.21.tar.gz',
+			'CPAN'               => 'ANDK/CPAN-1.92_60.tar.gz',
+		},
+	);
+}
+
 sub install_perl_modules {
 	my $self = shift;
 	$self->SUPER::install_perl_modules(@_);
@@ -114,6 +115,11 @@ sub install_perl_modules {
 		name => 'CGI',
 	);
 
+	# Install Wx as preparation for Chocolate
+	$self->install_module(
+		name => 'Wx',
+	);
+
 	return 1;
 }
 
@@ -131,28 +137,12 @@ sub remove_waste {
 		[ qw{ c bin startup templates os2  } ],
 		[ qw{ c bin startup templates unix } ],
 	) {
-		File::Remove::remove( \1, $self->dir(@$dir) );
+		File::Remove::remove( \1, $self->_dir(@$dir) );
 	}
 
 	return 1;
 }
 
-sub patch_include_path {
-	my $self    = shift;
-	my $include = $self->SUPER::patch_include_path;
-
-	# Add the extra vanilla directory
-	my $perl  = $self->perl_version_human;
-	my $share = File::ShareDir::dist_dir('Perl-Dist');
-	my $path  = File::Spec->catdir(
-		$share, 'vanilla',
-	);
-	unless ( -d $path ) {
-		die("Directory $path does not exist");
-	}
-	return [ @$include, $path ];
-}
-
 1;
 
 __END__
@@ -255,6 +245,18 @@ Once installed, you should add to the following environment variables.
         - C:\vanilla\c\bin
         - C:\vanilla\perl\bin 
 
+    * add directories to LIB
+        - C:\vanilla\c\lib
+        - C:\vanilla\perl\bin
+
+    * add directories to INCLUDE 
+        - C:\vanilla\c\include 
+        - C:\vanilla\perl\lib\CORE 
+
+LIB and INCLUDE changes are likely more than are necessary, but attempt to
+head off potential problems compiling external programs for use with Perl
+and various CPAN modules.
+
 The "cpan" program is pre-configured with a known-good setup, but you may
 wish to reconfigure it.
 
@@ -272,14 +274,33 @@ Bugs can be sent by email to C<<< bug-Perl-Dist-Vanilla@rt.cpan.org >>> or
 submitted using the web interface at
 L<http://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Dist-Vanilla>
 
-=head1 COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
 
-Copyright 2008 Adam Kennedy.
+Vanilla Perl is open source and may be licensed under the same terms as Perl.
+Open source software included with Vanilla Perl installations are governed by
+their respective licenses.  See LICENSE.txt for details.
 
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
+=head1 DISCLAIMER OF WARRANTY
 
-The full text of the license can be found in the
-LICENSE file included with this module.
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =cut
