@@ -1,12 +1,11 @@
 package t::lib::Test2;
 
 use strict;
-use Perl::Dist ();
+use base 'Perl::Dist';
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.05_04';
-	@ISA     = 'Perl::Dist';
+	$VERSION = '1.01';
 }
 
 
@@ -30,13 +29,6 @@ sub output_base_filename { 'test-perl-5.8.8-alpha-1' }
 #####################################################################
 # Main Methods
 
-sub new {
-	return shift->SUPER::new(
-		perl_version => 588,
-		@_,
-	);
-}
-
 sub run {
 	my $self = shift;
 
@@ -49,6 +41,12 @@ sub run {
 	# Install Perl 5.8.8
 	$self->install_perl_588;
 
+	# Install the CPAN configuration
+	$self->install_file(
+		share      => 'Perl-Dist Config.pm',
+		install_to => 'perl/lib/CPAN/Config.pm',
+	);
+
 	# Install a test distro
 	$self->install_distribution(
 		name => 'ADAMK/Config-Tiny-2.12.tar.gz',
@@ -63,14 +61,6 @@ sub install_binary {
 	return shift->SUPER::install_binary( @_, trace => sub { 1 } );
 }
 
-sub install_distribution {
-	return shift->SUPER::install_distribution( @_, trace => sub { 1 } );
-}
-
-sub install_file {
-	return shift->SUPER::install_file( @_, trace => sub { 1 } );
-}
-
 sub install_perl_588_bin {
 	return shift->SUPER::install_perl_588_bin( @_, trace => sub { 1 } );
 }
@@ -79,4 +69,12 @@ sub install_perl_588_toolchain {
 	return shift->SUPER::install_perl_588_toolchain( @_, trace => sub { 1 } );
 }
 
+sub install_distribution {
+	return shift->SUPER::install_distribution( @_, trace => sub { 1 } );
+}
+
+sub install_file {
+	return shift->SUPER::install_file( @_, trace => sub { 1 } );
+}
+
 1;
