@@ -1,12 +1,11 @@
 package t::lib::Test3;
 
 use strict;
-use Perl::Dist ();
+use base 'Perl::Dist';
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.05_04';
-	@ISA     = 'Perl::Dist';
+	$VERSION = '1.01';
 }
 
 
@@ -28,13 +27,52 @@ sub output_base_filename { 'test-perl-5.10.0-alpha-1' }
 
 
 #####################################################################
-# Main Methods
+# Constructor
 
 sub new {
-	return shift->SUPER::new(
-		perl_version => 5100,
-		@_,
+	my $class = shift;
+	my $self  = $class->SUPER::new(@_);
+
+	# Add links
+	
+
+	return $self;
+}
+
+
+
+
+
+#####################################################################
+# Main Methods
+
+sub run {
+	my $self = shift;
+
+	# Install the core binaries
+	$self->install_c_toolchain;
+
+	# Install the extra libraries
+	$self->install_c_libraries;
+
+	# Install Perl 5.10.0
+	$self->install_perl_5100;
+
+	# Install the CPAN configuration
+	# $self->install_file(
+	#	share      => 'Perl-Dist Config.pm',
+	#	install_to => 'perl/lib/CPAN/Config.pm',
+	# );
+
+	# Install a test distro
+	$self->install_distribution(
+		name => 'ADAMK/Config-Tiny-2.12.tar.gz',
 	);
+
+	# Generate the exe file
+	my $output = $self->write_exe;
+	print "Generated $output\n";
+	return 1;
 }
 
 sub trace { Test::More::diag($_[1]) }
